This crate contains kube-rs compatible bindings for Kubernetes custom resources for the site.superedge.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
site.superedge.io/v1alpha1
NodeGroupNodeUnit